@@ -111,6 +111,10 @@ class Channel(channel.Channel):
     def __exit__(self, *exc_info):
         self.close()
 
+    @property
+    def channel_id(self):
+        return self.channel_number
+
 
 class BlockingConnection(blocking_adapter.BlockingConnection):
 
@@ -183,9 +187,9 @@ class SyncTransport(base.Transport):
         if not conninfo.hostname:
             raise KeyError("Missing hostname for AMQP connection.")
         if conninfo.userid is None:
-            raise KeyError("Missing user id for AMQP connection.")
+            conninfo.userid = "guest"
         if conninfo.password is None:
-            raise KeyError("Missing password for AMQP connection.")
+            conninfo.password = "guest"
         if not conninfo.port:
             conninfo.port = self.default_port
 
